@@ -1,3 +1,7 @@
+#' datasummary statistic shortcut
+#' @export
+#' @keywords internal
+N <- function(x) sprintf("%.0f", length(x))
 
 #' datasummary statistic shortcut
 #' @export
@@ -26,6 +30,9 @@ Median <- function(x, fmt = NULL, na.rm = TRUE, ...) {
 #' @keywords internal
 Min <- function(x, fmt = NULL, na.rm = TRUE, ...) {
   out <- min(x, na.rm = na.rm)
+  if (is.integer(x)) {
+    out <- sprintf("%.0f", out)
+  }
   if (!is.null(fmt)) {
     out <- rounding(out, fmt)
   }
@@ -37,6 +44,9 @@ Min <- function(x, fmt = NULL, na.rm = TRUE, ...) {
 #' @keywords internal
 Max <- function(x, fmt = NULL, na.rm = TRUE, ...) {
   out <- max(x, na.rm = na.rm)
+  if (is.integer(x)) {
+    out <- sprintf("%.0f", out)
+  }
   if (!is.null(fmt)) {
     out <- rounding(out, fmt)
   }
