@@ -18,7 +18,6 @@ factory <- function(tab,
 
 
   # sanity check functions are hosted in R/sanity_checks.R
-  # more sanity checks are conducted in modelsummary:::extract_models()
   sanity_output(output)
   sanity_title(title)
   sanity_notes(notes)
@@ -81,7 +80,7 @@ factory <- function(tab,
       tmp <- matrix('', ncol = ncol(add_columns), nrow = nrow_gap)
       tmp <- data.frame(tmp)
       colnames(tmp) <- colnames(add_columns)
-      add_columns <- dplyr::bind_rows(add_columns, tmp)
+      add_columns <- bind_rows(add_columns, tmp)
     }
 
     # append
@@ -89,9 +88,9 @@ factory <- function(tab,
       if (!is.null(pos) && !is.na(pos[i])) {
         lef <- tab[, -c(pos[i]:ncol(tab)), drop=FALSE]
         rig <- tab[, c(pos[i]:ncol(tab)), drop=FALSE]
-        tab <- dplyr::bind_cols(lef, add_columns[i], rig)
+        tab <- bind_cols(lef, add_columns[i], rig)
       } else {
-        tab <- dplyr::bind_cols(tab, add_columns[i])
+        tab <- bind_cols(tab, add_columns[i])
       }
     }
 
@@ -112,12 +111,13 @@ factory <- function(tab,
     # data.frame includes metadata columns
     if (output_list$output_format == "dataframe") {
       # only for modelsummary, not for datasummary
+
       if (all(c("term", "statistic") %in% colnames(tab))) {
-        add_rows <- add_rows %>%
-          dplyr::mutate(group = "manual", statistic = "") %>%
-          dplyr::relocate(group, .before = term) %>%
-          dplyr::relocate(statistic, .after = term)
+        add_rows$part <- "manual"
+        add_rows$statistic <- ""
+        add_rows <- add_rows[, colnames(tab)]
       }
+
     }
 
     # sanity check
@@ -141,9 +141,9 @@ factory <- function(tab,
       if (!is.null(pos) && !is.na(pos[i])) {
         top <- tab[-c(pos[i]:nrow(tab)), , drop=FALSE]
         bot <- tab[c(pos[i]:nrow(tab)), , drop=FALSE]
-        tab <- dplyr::bind_rows(top, add_rows[i, , drop=FALSE], bot)
+        tab <- bind_rows(top, add_rows[i, , drop=FALSE], bot)
       } else {
-        tab <- dplyr::bind_rows(tab, add_rows[i, , drop=FALSE])
+        tab <- bind_rows(tab, add_rows[i, , drop=FALSE])
       }
     }
   }
