@@ -1,9 +1,17 @@
 # https://stackoverflow.com/questions/9439256/how-can-i-handle-r-cmd-check-no-visible-binding-for-global-variable-notes-when#comment20826625_12429344
 # 2012 hadley says "globalVariables is a hideous hack and I will never use it"
 # 2014 hadley updates his own answer with globalVariables as one of "two solutions"
-globalVariables(c('.', 'term', 'group', 'estimate', 'conf.high', 'conf.low', 'value', 'p.value', 'std.error', 'statistic', 'stars_note', 'logLik', 'formatBicLL', 'section', 'position', 'where', 'ticks', 'statistic1', 'model', 'tmp_grp', 'condition_variable'))
+globalVariables(c('.', 'term', 'part', 'estimate', 'conf.high', 'conf.low', 'value', 'p.value', 'std.error', 'statistic', 'stars_note', 'logLik', 'formatBicLL', 'section', 'position', 'where', 'ticks', 'statistic1', 'model', 'tmp_grp', 'condition_variable'))
 
 
+#' Deprecated function
+#'
+#' @param ... any argument
+#' @export
+extract_models <- function(...) {
+  stop('This function is deprecated. Consider using `modelsummary(output="data.frame")` instead.')
+}
+
 #' Beautiful, customizable summaries of statistical models
 #'
 #' @param models a single model object or a (potentially named) list of models
@@ -26,20 +34,19 @@ globalVariables(c('.', 'term', 'group', 'estimate', 'conf.high', 'conf.low', 'va
 #'   \item TRUE: *=.1, **=.05, ***=.01
 #'   \item Named numeric vector for custom stars such as `c('*' = .1, '+' = .05)`
 #' }
-#' @param statistic string name of the statistic to include in parentheses
+#' @param statistic character vector of raw strings or glue strings (see examples) which represent the uncertainty statistics to report vertically. Parentheses are added automatically unless the value includes `glue` curly braces {}. Acceptable values:
 #' \itemize{
-#'   \item Typical values: "conf.int", "std.error", "statistic", "p.value"
+#'   \item Typical values: "conf.int", "std.error", "statistic", "p.value", "conf.low", "conf.high".
 #'   \item Alternative values: any column name produced by `broom::tidy(model)`
+#'   \item `glue` package strings with braces such as: 
+#'   \item "\{estimate\} [\{conf.low\}, \{conf.high\}]"
 #' }
-#' @param statistic_override manually override the uncertainy estimates. This
-#' argument accepts three types of input:
+#' @param statistic_override manually override statistics. Accepts three types of input:
 #' \itemize{
-#'   \item a function or list of functions of length(models) which produce variance-covariance matrices with row and column names equal to the names of your coefficient estimates. For example, `R` supplies the `vcov` function, and the `sandwich` package supplies `vcovHC`, `vcovHAC`, etc.
+#'   \item a function or list of functions of length(models) which produce variance-covariance matrices with row and column names equal to the names of your coefficient estimates. For example, `R` supplies the `vcov` function, and the `sandwich` package supplies `vcovHC`, `vcovHAC`, etc. If the `lmtest` package is installed, `modelsummary` will try to use it to override: "std.error", "statistic", "p.value", "conf.int". If the `lmtest` package is not installed, `modelsummary` will override "std.error" by using the square root of the vcov matrix diagonal.
 #'   \item a list of length(models) variance-covariance matrices with row and column names equal to the names of your coefficient estimates.
 #'   \item a list of length(models) vectors with names equal to the names of your coefficient estimates. Numeric vectors are formatted according to `fmt` and placed in brackets, character vectors printed as given.
 #' }
-#' @param statistic_vertical TRUE if statistics should be printed below
-#' estimates. FALSE if statistics should be printed beside estimates.
 #' @param conf_level confidence level to use for confidence intervals
 #' @param coef_map named character vector. Values refer to the variable names
 #' that will appear in the table. Names refer to the original term names stored
@@ -53,7 +60,9 @@ globalVariables(c('.', 'term', 'group', 'estimate', 'conf.high', 'conf.low', 'va
 #' in the model object, e.g. c("hp:mpg"="hp X mpg") for an interaction term.
 #' @param gof_map data.frame with four columns: `raw`, `clean`, `fmt`, and
 #' `omit`. If `gof_map` is NULL, then `modelsummary` will use this data frame
-#' by default: `modelsummary::gof_map`
+#' by default: `modelsummary::gof_map` By default, all the statistics produced
+#' by `broom::glance` will be included unless they are omitted explicitly in
+#' `gof_map`.
 #' @param gof_omit string regular expression. Omits all matching gof statistics from
 #' the table (using `grepl(perl=TRUE)`).
 #' @param add_rows a data.frame (or tibble) with the same number of columns as
@@ -71,7 +80,9 @@ globalVariables(c('.', 'term', 'group', 'estimate', 'conf.high', 'conf.low', 'va
 #' @param ... all other arguments are passed to the `tidy` and `glance` methods
 #' used to extract estimates from the model. For example, this allows users to
 #' set `exponentiate=TRUE` to exponentiate logistic regression coefficients.
+#' @param statistic_vertical deprecated argument. Supply a vector of strings or `glue` strings to the `estimate` instead.
 #' @return a regression table in a format determined by the `output` argument.
+#' @importFrom generics glance tidy
 #' @examples
 #' \dontrun{
 #'
@@ -125,80 +136,206 @@ globalVariables(c('.', 'term', 'group', 'estimate', 'conf.high', 'conf.low', 'va
 #' # see the README on github for a lot more examples:
 #' # https://github.com/vincentarelbundock/modelsummary
 #' @export
-modelsummary <- function(models,
-                         output = "default",
-                         fmt = 3,
-                         statistic = 'std.error',
-                         statistic_override = NULL,
-                         statistic_vertical = TRUE,
-                         conf_level = 0.95,
-                         stars = FALSE,
-                         coef_map = NULL,
-                         coef_omit = NULL,
-                         coef_rename = NULL,
-                         gof_map = NULL,
-                         gof_omit = NULL,
-                         add_rows = NULL,
-                         title = NULL,
-                         notes = NULL,
-                         align = NULL,
-                         estimate = 'estimate',
-                         ...) {
+modelsummary <- function(
+  models,
+  output = "default",
+  fmt = 3,
+  statistic = "std.error",
+  statistic_override = NULL,
+  stars = FALSE,
+  conf_level = 0.95,
+  coef_map = NULL,
+  coef_omit = NULL,
+  coef_rename = NULL,
+  gof_map = NULL,
+  gof_omit = NULL,
+  estimate = "estimate",
+  add_rows = NULL,
+  title = NULL,
+  notes = NULL,
+  align = NULL,
+  statistic_vertical = NULL,
+  ...) {
 
+  # sanity check functions are hosted in R/sanity_checks.R
+  sanity_output(output)
+  sanity_statistic(statistic)
+  sanity_estimate(estimate)
+  sanity_statistic_override(models, statistic_override)
+  sanity_conf_level(conf_level)
+  sanity_coef(coef_map, coef_rename, coef_omit)
+  # sanity_gof(gof_map, gof_omit)
+  sanity_stars(stars)
+  sanity_fmt(fmt)
+
+  # deprecation: statistic, statistic_override, statistic_vertical
+  if (!is.null(statistic_vertical)) {
+    warning("The `statistic_vertical` argument is deprecated. To present
+            uncertainty estimates next to the main estimate, you can supply a
+            `glue` string to the `estimate` argument. See examples.")
+  }
+
+  # output
+  output_format <- parse_output_arg(output)$output_format
+
+  # extra arguments
   ellipsis <- list(...)
 
-  # sanity checks for arguments not present in extract_models
-  sanity_output(output)
+  # models must be a list
+  if (!inherits(models, "list")) {
+    models <- list(models)
+  }
 
-  # extract estimates and gof
-  dat <- extract_models(
-    models,
-    statistic = statistic,
-    statistic_override = statistic_override,
-    statistic_vertical = statistic_vertical,
-    conf_level = conf_level,
-    coef_map = coef_map,
-    coef_omit = coef_omit,
-    coef_rename = coef_rename,
-    gof_map = gof_map,
-    gof_omit = gof_omit,
-    stars = stars,
-    fmt = fmt,
-    estimate = estimate,
-    ...)
+  # model names dictionary: use unique names for manipulation
+  if (is.null(names(models))) {
+    model_names <- paste("Model", 1:length(models))
+  } else {
+    model_names <- names(models)
+  }
+  model_id <- paste("Model", 1:length(models))
 
-  # remove duplicate term labels
-  idx <- grepl('statistic\\d*$', dat$statistic)
-  tab <- dat %>%
-    dplyr::mutate(term = ifelse(idx, '', term))
+  # statistic_override must be a list
+  if (!inherits(statistic_override, "list")) {
+    statistic_override <- rep(list(statistic_override), length(models))
+  }
+
+  # estimates: extract and combine
+  est <- list()
+
+  for (i in seq_along(models)) {
+
+    tmp <- extract_estimates(
+      model              = models[[i]],
+      fmt                = fmt,
+      estimate           = estimate,
+      statistic          = statistic,
+      statistic_override = statistic_override[[i]],
+      conf_level         = conf_level,
+      stars              = stars,
+      ...
+    )
+
+    # coef_rename: before merge to collapse rows
+    if (!is.null(coef_rename)) {
+      tmp$term <- replace_dict(tmp$term, coef_rename)
+    }
+
+    # coef_map
+    if (!is.null(coef_map)) {
+      tmp <- tmp[tmp$term %in% names(coef_map), , drop=FALSE]
+      tmp$term <- replace_dict(tmp$term, coef_map)
+    }
+
+    # coef_omit
+    if (!is.null(coef_omit)) {
+      idx <- !grepl(coef_omit, tmp$term, perl=TRUE)
+      tmp <- tmp[idx, , drop=FALSE]
+    }
+
+    # make sure no duplicate estimate names *within* a single model. this
+    # cannot be in input sanity checks. idx paste allows multiple statistics.
+    idx <- paste(tmp$term, tmp$statistic)
+    if (anyDuplicated(idx) > 2) {
+      stop('Two coefficients from a single model cannot share the same name. Check model ', i)
+    }
+
+    # model name is temporarily a unique id
+    colnames(tmp)[3] <- model_id[i]
+
+    # assign
+    est[[model_id[i]]] <- tmp
+
+  }
+
+  term_order <- lapply(est, function(x) x$term)
+  term_order <- unique(unlist(term_order))
+
+  f <- function(x, y) merge(x, y, all=TRUE, sort=FALSE, by=c("term", "statistic"))
+  est <- Reduce(f, est) 
+  est$part <- "estimates"
+  est <- est[, unique(c("part", "term", "statistic", names(est)))]
+
+  # default order
+  idx <- match(est[["term"]], term_order)
+  est <- est[order(idx, est[["statistic"]]),]
+
+  # coef_map
+  if (!is.null(coef_map)) {
+    coef_map <- intersect(coef_map, term_order)
+    est <- est[est[["term"]] %in% coef_map, , drop=FALSE]
+    idx <- match(est[["term"]], coef_map)
+    est <- est[order(idx, est[["statistic"]]),]
+  }
+
+  # gof: extract and combine
+  gof <- list()
+
+  for (i in seq_along(models)) {
+    gof[[i]] <- extract_gof(models[[i]], fmt=fmt, gof_map=gof_map, ...)
+    colnames(gof[[i]])[2] <- model_id[i]
+  }
+
+  f <- function(x, y) merge(x, y, all=TRUE, sort=FALSE, by="term")
+  gof <- Reduce(f, gof)
+
+  if (nrow(gof) > 0) {
+
+    # gof row identifier
+    gof$part <- "gof"
+    gof <- gof[, unique(c("part", "term", names(gof)))]
+
+    # gof_omit
+    if (!is.null(gof_omit)) {
+      idx <- !grepl(gof_omit, gof$term, perl=TRUE)
+      gof <- gof[idx, , drop=FALSE]
+    }
+
+    # gof_map
+    if (nrow(gof) > 0) {
+      if (is.null(gof_map)) {
+        # assign here and not in the function definition because we use NULL to
+        # figure out if F-stat should be included by default for lm models.
+        gof_map <- get("gof_map", as.environment("package:modelsummary"))
+      }
+      gof <- gof[!gof$term %in% gof_map$raw[gof_map$omit], , drop=FALSE]
+      gof_names <- gof_map$clean[match(gof$term, gof_map$raw)]
+      gof_names[is.na(gof_names)] <- gof$term[is.na(gof_names)]
+      gof$term <- gof_names
+      idx <- match(gof$term, gof_map$clean)
+      gof <- gof[order(idx, gof$term), ]
+    }
+
+  } 
+
+  # combine estimates and gof
+  if (nrow(gof) > 0) {
+    tab <- bind_rows(est, gof)
+  } else {
+    tab <- est
+  }
+
+  # empty cells
+  tab[is.na(tab)] <- ''
 
   # interaction : becomes ×
   if (is.null(coef_map)) {
-    if (parse_output_arg(output)$output_format != 'rtf') {
-      idx <- tab$group != 'gof'
+    if (output_format != 'rtf') {
+      idx <- tab$part != 'gof'
       tab$term <- ifelse(idx, gsub(':', ' \u00d7 ', tab$term), tab$term)
     }
   }
 
   # measure table
-  hrule <- match('gof', tab$group)
+  hrule <- match('gof', tab$part)
   if (!is.na(hrule) &&
-    !is.null(add_rows) &&
-    !is.null(attr(add_rows, 'position'))) {
+      !is.null(add_rows) &&
+      !is.null(attr(add_rows, 'position'))) {
     hrule <- hrule + sum(attr(add_rows, 'position') < hrule)
   }
   if (is.na(hrule)) {
     hrule <- NULL
   }
 
-  # clean table but keep metadata for data.frame output
-  if (parse_output_arg(output)$output_format != "dataframe") {
-    tab <- tab %>%
-      dplyr::select(-statistic, -group) %>%
-      # HACK: arbitrary 7 spaces to avoid name conflict
-      dplyr::rename(`       ` = term)
-  }
-
   # stars
   if (!isFALSE(stars)) {
     stars_note <- make_stars_note(stars)
@@ -209,13 +346,37 @@ modelsummary <- function(models,
     }
   }
 
-  # column alignment
+
+  # data.frame output keeps redundant info
+  if (output_format != "dataframe") {
+
+    # duplicate term labels
+    idx <- grepl("modelsummary_tmp\\d+$", tab$statistic) &
+           tab$statistic != "modelsummary_tmp1"
+    tab$term[idx] <- ""
+
+    # clean table but keep metadata for data.frame output
+    if (output_format != "dataframe") {
+      tab$statistic <- tab$part <- NULL
+
+      # HACK: arbitrary 7 spaces to avoid name conflict
+      colnames(tab)[colnames(tab)=="term"] <- "       "
+    }
+
+  }
+
+  # column alignment (after removing extraneous columns)
   if (is.null(align)) {
     align <- paste0("l", strrep("c", ncol(tab) - 1))
   }
 
+  # restore original model names
+  idx <- match(model_id, colnames(tab))
+  colnames(tab)[idx] <- model_names
+
   # build table
-  factory(tab,
+  factory(
+    tab,
     align = align,
     fmt = fmt,
     hrule = hrule,
@@ -223,7 +384,8 @@ modelsummary <- function(models,
     output = output,
     title = title,
     add_rows = add_rows,
-    ...)
+    ...
+  )
 
 }
 
