@@ -40,7 +40,14 @@ sanity_align <- function(align, tab) {
 #' sanity check
 #'
 #' @keywords internal
-sanity_estimate <- function(estimate) checkmate::assert_character(estimate)
+sanity_estimate <- function(estimate) checkmate::assert_character(estimate, len=1)
+
+#' sanity_check
+#'
+#' @keywords internal
+sanity_statistic <- function(statistic) {
+  checkmate::assert_character(statistic, null.ok=TRUE)
+}
 
 #' sanity check
 #'
@@ -50,26 +57,26 @@ sanity_title <- function(title) checkmate::assert_character(title, len = 1, null
 #' sanity check
 #'
 #' @keywords internal
-sanity_coef_map <- function(coef_map) {
-  checkmate::assert_character(coef_map, null.ok = TRUE)
-  checkmate::assert_character(names(coef_map), null.ok = TRUE,
-    unique = TRUE)
+sanity_coef <- function(coef_map, coef_rename, coef_omit) {
+  checkmate::assert_character(coef_map, null.ok=TRUE)
+  checkmate::assert_character(names(coef_map), null.ok=TRUE, unique=TRUE)
+  checkmate::assert_character(coef_rename, null.ok=TRUE)
+  checkmate::assert_character(names(coef_rename), null.ok=TRUE, unique=TRUE)
+  checkmate::assert_string(coef_omit, null.ok = TRUE)
+  if (!is.null(coef_rename) & !is.null(coef_map)) {
+    stop("coef_map and coef_rename cannot be used together.")
+  }
 }
 
-#' sanity check
-#'
-#' @keywords internal
-sanity_coef_omit <- function(coef_omit) checkmate::assert_string(coef_omit, null.ok = TRUE)
 
 #' sanity check
 #'
 #' @keywords internal
-sanity_gof_omit <- function(gof_omit) checkmate::assert_string(gof_omit, null.ok = TRUE)
+sanity_gof <- function(gof_map, gof_omit) {
+  checkmate::assert_string(gof_omit, null.ok = TRUE)
+  checkmate::assert_data_frame(gof_map, null.ok = TRUE)
+}
 
-#' sanity check
-#'
-#' @keywords internal
-sanity_gof_map <- function(gof_map) checkmate::check_data_frame(gof_map, null.ok = TRUE)
 
 #' sanity check
 #'
@@ -194,33 +201,28 @@ sanity_add_rows <- function(add_rows, models) {
 #' sanity check
 #'
 #' @keywords internal
-sanity_statistic <- function(statistic,
-                             statistic_override,
-                             statistic_vertical,
-                             models) {
+sanity_statistic_override <- function(models, statistic_override) {
 
-  checkmate::assert_character(statistic)
+  checkmate::assert(
+    checkmate::check_list(statistic_override, null.ok = TRUE),
+    checkmate::check_function(statistic_override, null.ok = TRUE),
+    checkmate::check_matrix(statistic_override, null.ok = TRUE),
+    checkmate::check_atomic_vector(statistic_override),
+    combine="or"
+  )
 
-  checkmate::assert(checkmate::check_list(statistic_override, null.ok = TRUE),
-    checkmate::check_function(statistic_override, null.ok = TRUE))
-
-  if (is.list(statistic_override)) {
+  if (class(statistic_override)[1] == "list" &
+      class(models)[1] == "list") { # must be simple lists
     checkmate::assert_true(length(statistic_override) == length(models))
-    checkmate::assert(checkmate::check_true(all(sapply(statistic_override, is.function))),
-      checkmate::check_true(all(sapply(statistic_override, is.vector))),
-      checkmate::check_true(all(sapply(statistic_override, is.matrix))))
-  } else if (is.function(statistic_override)) {
-    statistic_override <- lapply(models, function(x) statistic_override)
-  }
-
-  # statistic_vertical = FALSE: only one statistic can be displayed horizontally
-  checkmate::assert_logical(statistic_vertical, len = 1, null.ok = FALSE)
-  if (!statistic_vertical) {
-    if (length(statistic) > 1 | (length(statistic_override) > 1) & !is.vector(statistic_override[1])) {
-      stop("Only one statistic can be displayed next to the estimate. Check the statistic_vertical argument.")
-
+    for (s in statistic_override) {
+      checkmate::assert(
+        checkmate::check_function(s),
+        checkmate::check_matrix(s),
+        checkmate::check_vector(s),
+        combine="or"
+      )
     }
-  }
+  } 
 }
 
 #' sanity check
@@ -248,31 +250,6 @@ sanity_tidy <- function(tidy_output, tidy_custom, estimate, statistic, modelclas
     checkmate::assert_true('term' %in% colnames(tidy_custom))
     checkmate::assert_true(all(tidy_output$term == tidy_custom$term))
   }
-
-  # columns
-  available <- c(colnames(tidy_output), colnames(tidy_custom))
-
-  if (!estimate %in% available) {
-    msg <- paste0('For models of class ',
-      modelclass,
-      ' the `estimate` argument of the `modelsummary()` function must be one of: ',
-      paste(available, collapse = ', '))
-    stop(msg)
-  }
-
-  statistic[statistic == 'conf.int'] <- 'conf.low'
-  if (!all(statistic %in% available)) {
-    if ('conf.low' %in% available) {
-      available <- base::setdiff(available, c('conf.low', 'conf.high'))
-      available <- c('conf.int', available)
-    }
-    msg <- paste0('For models of class ',
-      modelclass,
-      ' the `statistic` argument of the `modelsummary()` function must be one of: ',
-      paste(available, collapse = ', '),
-      ' (or possibly conf.int)')
-    stop(msg)
-  }
 }
 
 #' sanity check: datasummary
