@@ -19,13 +19,13 @@ clean_stars <- function(stars) {
 #' Internal function to prepare stars
 #'
 #' @keywords internal
-make_stars <- function(x, pvalues, stars) {
+make_stars <- function(pvalues, stars) {
   stars <- clean_stars(stars)
   tmp <- ""
   for (n in names(stars)) {
     tmp <- ifelse(pvalues <= stars[n], n, tmp)
   }
-  paste0(x, tmp)
+  tmp
 }
 
 
